# LatencyHistogramBuckets

A latency bucket and its measurement. Part of a latency historgram 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bucket** | **float** | Identifies the bucket. This bucket will count all instances where the latency was less than or equal to this value.  | 
**value** | **int** | The number of times the measured time of something fell in to this bucket.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


